@@ -1,6 +1,6 @@
 structure(list(method = "GET", url = "https://soda.demo.socrata.com/resource/jatp-jqxg.json?%24select=time%2C%20updated&%24offset=10000&%24limit=10000", 
     status_code = 200L, headers = structure(list(Server = "nginx", 
-        Date = "Tue, 22 Jul 2025 20:42:12 GMT", `Content-Type` = "application/json;charset=utf-8", 
+        Date = "Mon, 18 Aug 2025 16:31:18 GMT", `Content-Type` = "application/json;charset=utf-8", 
         `Transfer-Encoding` = "chunked", Connection = "keep-alive", 
         `Access-Control-Allow-Origin` = "*", ETag = "\"Zm94dHJvdC4zMDE4MV8yXzIxQnRESC1ETVRyMXNXc1g5TV9wdUs3TXVuTHd3--gziqQD655wdJ2DgKUpuyeEr8HoVEUI---gzip\"", 
         `X-SODA2-Fields` = "[\"time\",\"updated\"]", `X-SODA2-Types` = "[\"floating_timestamp\",\"floating_timestamp\"]", 
@@ -9,7 +9,7 @@ structure(list(method = "GET", url = "https://soda.demo.socrata.com/resource/jat
         `Last-Modified` = "Tue, 26 Apr 2016 23:01:08 GMT", Vary = "Accept-Encoding", 
         `Content-Encoding` = "gzip", Age = "0", `X-Socrata-Region` = "aws-us-east-1-fedramp-prod", 
         `Strict-Transport-Security` = "max-age=31536000; includeSubDomains", 
-        `X-Socrata-RequestId` = "7af278321d97422daaeea0c225667a31"), class = "httr2_headers"), 
-    body = charToRaw("[]\n"), timing = c(redirect = 0, namelookup = 1.6e-05, 
-    connect = 0, pretransfer = 7.7e-05, starttransfer = 0.201029, 
-    total = 0.201075), cache = new.env(parent = emptyenv())), class = "httr2_response")
+        `X-Socrata-RequestId` = "b9e85890924437b22a4ba7c325e4b4aa"), class = "httr2_headers"), 
+    body = charToRaw("[]\n"), timing = c(redirect = 0, namelookup = 1.2e-05, 
+    connect = 0, pretransfer = 7.6e-05, starttransfer = 0.139897, 
+    total = 0.139953), cache = new.env(parent = emptyenv())), class = "httr2_response")
